@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -33,7 +33,7 @@ public:
     DeintSettingsW();
     ~DeintSettingsW();
 
-    void setSoftwareDeintEnabledDisabled();
+    void setDeintEnabledDisabled();
 
     void writeSettings();
 private slots:
