@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -35,7 +35,7 @@ public:
         Q_DECLARE_TR_FUNCTIONS(Window)
     public:
         Window(MenuBar *parent);
-        QAction *toggleVisibility, *toggleFullScreen, *toggleCompactView, *alwaysOnTop, *hideOnClose, *close;
+        QAction *toggleVisibility, *toggleFullScreen, *toggleCompactView, *alwaysOnTop = nullptr, *hideOnClose, *close;
     };
 
     class Widgets : public QMenu
@@ -72,7 +72,7 @@ public:
         Add *add;
         QMenu *extensions;
         Sort *sort;
-        QAction *stopLoading, *sync, *quickSync, *loadPlist, *savePlist, *saveGroup, *lock, *alwaysSync, *delEntries, *delNonGroupEntries, *clear, *copy, *paste, *newGroup, *renameGroup, *find, *collapseAll, *expandAll, *goToPlayback, *queue, *skip, *stopAfter, *entryProperties;
+        QAction *stopLoading, *sync, *quickSync, *loadPlist, *savePlist, *saveGroup, *lock, *alwaysSync, *delEntries, *delEntriesFromDisk, *delNonGroupEntries, *clear, *copy, *paste, *pasteAndPlay, *newGroup, *renameGroup, *find, *collapseAll, *expandAll, *goToPlayback, *queue, *skip, *stopAfter, *entryProperties;
     };
 
     class Player : public QMenu
@@ -89,13 +89,20 @@ public:
             QActionGroup *choice;
             QAction *repeatActions[RepeatModeCount];
         };
+        class Zoom : public QMenu
+        {
+            Q_DECLARE_TR_FUNCTIONS(Zoom)
+        public:
+            Zoom(QMenu *parent);
+            QAction *integerScaling, *preciseZoom, *zoomIn, *zoomOut, *setZoom;
+        };
         class AspectRatio : public QMenu
         {
             Q_DECLARE_TR_FUNCTIONS(AspectRatio)
         public:
             AspectRatio(QMenu *parent);
             QActionGroup *choice;
-            QAction *_auto, *_1x1, *_4x3, *_5x4, *_16x9, *_3x2, *_21x9, *sizeDep, *off;
+            QAction *_auto, *_1x1, *_4x3, *_5x4, *_16x9, *_3x2, *_21x9, *sizeDep, *custom, *off;
         };
 
         void seekActionsEnable(bool e);
@@ -103,7 +110,8 @@ public:
 
         Repeat *repeat;
         AspectRatio *aRatio;
-        QAction *togglePlay, *stop, *next, *prev, *prevFrame, *nextFrame, *abRepeat, *seekF, *seekB, *lSeekB, *lSeekF, *speedUp, *slowDown, *setSpeed, *switchARatio, *zoomIn, *zoomOut, *reset, *continuePlayback, *volUp, *volDown, *toggleMute, *detach;
+        Zoom *zoom;
+        QAction *togglePlay, *stop, *next, *prev, *rec, *prevFrame, *nextFrame, *abRepeat, *seekF, *seekB, *lSeekB, *lSeekF, *speedUp, *slowDown, *setSpeed, *switchARatio, *reset, *continuePlayback, *volUp, *volDown, *toggleMute, *detach;
         QAction *suspend = nullptr;
     };
 
