@@ -21,6 +21,7 @@
 
 #include <EntryProperties.hpp>
 #include <LineEdit.hpp>
+#include <Settings.hpp>
 #include <Main.hpp>
 
 #include <QFileInfo>
@@ -57,6 +58,8 @@ PlaylistDock::PlaylistDock() :
     findE->setToolTip(tr("Filter entries"));
     statusL = new QLabel;
 
+    setMode();
+
     QGridLayout *layout = new QGridLayout(&mainW);
     layout->addWidget(list);
     layout->addWidget(findE);
@@ -126,6 +129,7 @@ bool PlaylistDock::save(const QString &_url, bool saveCurrentGroup)
         if (tWI == list->currentItem())
             entry.flags |= Playlist::Entry::Selected;
         entry.flags |= PlaylistWidget::getFlags(tWI); //Additional flags
+        entry.params = tWI->data(0, Qt::UserRole + 1).value<QHash<QByteArray, QByteArray>>();
         entries += entry;
     }
     return Playlist::write(entries, url);
@@ -210,6 +214,25 @@ void PlaylistDock::scrollToCurrectItem()
     list->scrollToItem(list->currentItem());
 }
 
+void PlaylistDock::setMode()
+{
+    if (QMPlay2Core.getSettings().getBool("CompactPlaylist"))
+    {
+        list->setIconSize({16, 16});
+        findE->clear();
+        findE->hide();
+        statusL->hide();
+    }
+    else
+    {
+        list->setIconSize({22, 22});
+        if (findE->parentWidget())
+            findE->show();
+        if (statusL->parentWidget())
+            statusL->show();
+    }
+}
+
 void PlaylistDock::showEvent(QShowEvent *e)
 {
     DockWidget::showEvent(e);
@@ -341,7 +364,31 @@ void PlaylistDock::itemDoubleClicked(QTreeWidgetItem *tWI)
         list->refresh(PlaylistWidget::REFRESH_QUEUE);
     }
 
-    emit play(tWI->data(0, Qt::UserRole).toString());
+    const auto url = tWI->data(0, Qt::UserRole).toString();
+
+    if (!url.startsWith("file://"))
+    {
+        const auto params = tWI->data(0, Qt::UserRole + 1).value<QHash<QByteArray, QByteArray>>();
+        QByteArray rawHeaders;
+        for (auto it = params.cbegin(), itEnd = params.cend(); it != itEnd; ++it)
+        {
+            const auto &key = it.key();
+            if (key == Playlist::Entry::UserAgentParam)
+            {
+                rawHeaders += "Referer: " + it.value() + "\r\n";
+            }
+            else if (key == Playlist::Entry::ReferrerParam)
+            {
+                rawHeaders += "User-Agent: " + it.value() + "\r\n";
+            }
+        }
+        if (!rawHeaders.isEmpty())
+        {
+            QMPlay2Core.addRawHeaders(url, rawHeaders);
+        }
+    }
+
+    emit play(url);
 }
 void PlaylistDock::addAndPlay(QTreeWidgetItem *tWI)
 {
