@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -128,6 +128,10 @@ void VideoThr::stop(bool terminate)
     AVThread::stop(terminate);
 }
 
+bool VideoThr::hasError() const
+{
+    return m_error;
+}
 bool VideoThr::hasDecoderError() const
 {
     return decoderError;
@@ -138,6 +142,11 @@ AVPixelFormats VideoThr::getSupportedPixelFormats() const
     return videoWriter()->supportedPixelFormats();
 }
 
+void VideoThr::setTsDiscontPossible(bool tsDiscontPossible)
+{
+    m_tsDisontPossible = tsDiscontPossible;
+}
+
 void VideoThr::destroySubtitlesDecoder()
 {
     deleteSubs = true;
@@ -170,10 +179,10 @@ void VideoThr::setVideoAdjustment()
 {
     QMPlay2GUI.videoAdjustment->setModuleParam(writer);
 }
-void VideoThr::setFrameSize(int w, int h)
+void VideoThr::setFrameSize(const QSize &size)
 {
-    W = w;
-    H = h;
+    W = size.width();
+    H = size.height();
     writer->modParam("W", W);
     writer->modParam("H", H);
     deleteSubs = deleteOSD = deleteFrame = true;
@@ -186,10 +195,29 @@ void VideoThr::setARatio(double aRatio, const AVRational &sar)
     writer->modParam("AspectRatio", aRatio);
     lastSAR = sar;
 }
-void VideoThr::setZoom()
+void VideoThr::setZoom(double zoom)
 {
     updateSubs();
-    writer->modParam("Zoom", playC.zoom);
+    writer->modParam("Zoom", zoom);
+}
+
+void VideoThr::setSubtitlesScale(double subtitlesScale)
+{
+    playC.subsMutex.lock();
+    m_subtitlesScale = subtitlesScale;
+    if (m_subtitlesBusy)
+    {
+        auto locker = m_subtitlesBusy->lock();
+        if (m_subtitlesBusy->needsRescale())
+            m_subtitlesBusy->setScale(m_subtitlesScale);
+    }
+    if (m_subtitles)
+    {
+        auto locker = m_subtitles->lock();
+        if (m_subtitles->needsRescale())
+            m_subtitles->setScale(m_subtitlesScale);
+    }
+    playC.subsMutex.unlock();
 }
 
 void VideoThr::setColorInfo(AVColorPrimaries colorPrimaries, AVColorTransferCharacteristic colorTrc)
@@ -515,10 +543,12 @@ void VideoThr::run()
             {
                 gotFrameOrError = true;
                 err = true;
+                m_error = true;
             }
             else
             {
                 tmp_br += bytes_consumed;
+                m_error = false;
             }
             skipNonKey = false;
         }
@@ -592,6 +622,8 @@ void VideoThr::run()
             }
             else if (subsPts >= m_subtitles->pts())
             {
+                if (m_subtitles->needsRescale())
+                    m_subtitles->setScale(m_subtitlesScale);
                 m_subtitles->start();
                 osdList += m_subtitles;
             }
@@ -645,7 +677,7 @@ void VideoThr::run()
                 playC.chPos(ts);
 
             double delay = ts - playC.frame_last_pts;
-            if (useLastDelay || delay <= 0.0 || (playC.frame_last_pts <= 0.0 && delay > playC.frame_last_delay) || (delay > 1.0 && delay / playC.frame_last_delay > 10.0))
+            if (useLastDelay || delay <= 0.0 || (playC.frame_last_pts <= 0.0 && delay > playC.frame_last_delay) || (m_tsDisontPossible && delay > 1.0 && delay / playC.frame_last_delay > 10.0))
             {
                 delay = playC.frame_last_delay;
                 useLastDelay = false;
@@ -801,6 +833,8 @@ void VideoThr::run()
             Functions::s_wait(0.001);
         }
     }
+
+    m_error = false;
 }
 
 #ifdef Q_OS_WIN
