@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -120,6 +120,20 @@ bool FFDecSW::set()
         restartPlaying = true;
     }
 
+    int teletextPage = sets().getInt("TeletextPage");
+    if (m_teletextPage != teletextPage)
+    {
+        m_teletextPage = teletextPage;
+        restartPlaying = true;
+    }
+
+    bool teletextTransparent = sets().getBool("TeletextTransparent");
+    if (m_teletextTransparent != teletextTransparent)
+    {
+        m_teletextTransparent = teletextTransparent;
+        restartPlaying = true;
+    }
+
 #ifdef USE_VULKAN
     m_disableZeroCopy = sets().getBool("DisableZeroCopy");
 #endif
@@ -252,6 +266,8 @@ int FFDecSW::decodeAudio(const Packet &encodedPacket, QByteArray &decoded, doubl
             ts = frame->best_effort_timestamp * av_q2d(m_timeBase);
         else if (encodedPacket.hasDts() || encodedPacket.hasPts())
             ts = encodedPacket.ts();
+        else if (codec_ctx->codec_id == AV_CODEC_ID_APE && !qIsNaN(m_lastTs))
+            ts = m_lastTs + static_cast<double>(frame->nb_samples) / static_cast<double>(sampleRate);
         else
             ts = qQNaN();
     }
@@ -260,6 +276,8 @@ int FFDecSW::decodeAudio(const Packet &encodedPacket, QByteArray &decoded, doubl
         ts = qQNaN();
     }
 
+    m_lastTs = ts;
+
     return (bytesConsumed <= 0) ? 0 : bytesConsumed;
 }
 int FFDecSW::decodeVideo(const Packet &encodedPacket, Frame &decoded, AVPixelFormat &newPixFmt, bool flush, unsigned hurry_up)
@@ -470,9 +488,16 @@ bool FFDecSW::open(StreamInfo &streamInfo)
                 qDebug() << "Vulkan :: Zero-copy decoding is not supported";
             }
         }
+#endif
     }
     else if (codec_ctx->codec_type == AVMEDIA_TYPE_SUBTITLE)
     {
+        if (codec->id == AV_CODEC_ID_DVB_TELETEXT)
+        {
+            av_dict_set(&m_options, "txt_page", (m_teletextPage > 0) ? QByteArray::number(m_teletextPage).constData() : "subtitle", 0);
+            av_dict_set(&m_options, "txt_transparent", QByteArray::number(m_teletextTransparent), 0);
+        }
+#ifdef USE_VULKAN
         if (QMPlay2Core.isVulkanRenderer())
             m_vkBufferPool = static_pointer_cast<QmVk::Instance>(QMPlay2Core.gpuInstance())->createBufferPool();
 #endif
@@ -523,7 +548,7 @@ void FFDecSW::setPixelFormat()
 
     const QByteArray srcPixFmtName = srcPixDesc->name;
 
-    for (const AVPixelFormat pixFmt : qAsConst(m_supportedPixelFormats))
+    for (const AVPixelFormat pixFmt : std::as_const(m_supportedPixelFormats))
     {
         if (!sws_isSupportedOutput(pixFmt))
             continue;
@@ -643,10 +668,11 @@ bool FFDecSW::getFromBitmapSubsBuffer(shared_ptr<QMPlay2OSD> &osd, double pos)
             auto scaleRect = [this](const QRect &rect, const QSize &frameSize) {
                 const auto rx = static_cast<qreal>(frameSize.width())  / static_cast<qreal>(codec_ctx->width);
                 const auto ry = static_cast<qreal>(frameSize.height()) / static_cast<qreal>(codec_ctx->height);
+                const auto r = ry / rx;
                 QRectF newRect = rect;
-                if (!qFuzzyCompare(ry, rx))
+                if (r < 0.95)
                 {
-                    newRect.setSize(QSizeF(newRect.width() * ry / rx, newRect.height()));
+                    newRect.setWidth(newRect.width() * r);
                     newRect.translate(rect.width() / 2.0 - newRect.width() / 2.0, 0.0);
                 }
                 return QRectF(
