@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -565,7 +565,7 @@ void OpenGLCommon::paintGL()
             shaderProgramVideo->setUniformValue("uBitsMultiplier", m_bitsMultiplier);
         }
 
-        if (m_colorPrimaries == AVCOL_PRI_BT2020 && (m_colorTrc == AVCOL_TRC_BT709 || m_colorTrc == AVCOL_TRC_SMPTE2084))
+        if (m_colorPrimaries == AVCOL_PRI_BT2020 && (m_colorTrc == AVCOL_TRC_BT709 || m_colorTrc == AVCOL_TRC_SMPTE2084 || m_colorTrc == AVCOL_TRC_ARIB_STD_B67))
         {
             shaderProgramVideo->setUniformValue("uTrc", m_colorTrc);
             shaderProgramVideo->setUniformValue("uMaxLuminance", m_maxLuminance);
@@ -576,6 +576,8 @@ void OpenGLCommon::paintGL()
             shaderProgramVideo->setUniformValue("uTrc", 0);
         }
 
+        shaderProgramVideo->setUniformValue("uNegative", static_cast<int>(videoAdjustment.negative));
+
         shaderProgramVideo->setUniformValue("uTextureSize", m_textureSize);
 
         doReset = !resetDone;
@@ -656,10 +658,11 @@ void OpenGLCommon::paintGL()
         }
 
         const auto realWinSize = getRealWidgetSize();
-        const float left   = (bounds.left() + m_subsRect.x()) * 2.0f / realWinSize.width() - m_osdOffset.x();
-        const float right  = (bounds.right() + m_subsRect.x() + 1.0f) * 2.0f / realWinSize.width() - m_osdOffset.x();
-        const float top    = (bounds.top() + m_subsRect.y()) * 2.0f / realWinSize.height() - m_osdOffset.y();
-        const float bottom = (bounds.bottom() + m_subsRect.y() + 1.0f) * 2.0f / realWinSize.height() - m_osdOffset.y();
+        const auto osdOffset = getOsdOffset();
+        const float left   = (bounds.left() + m_subsRect.x()) * 2.0f / realWinSize.width() - osdOffset.x();
+        const float right  = (bounds.right() + m_subsRect.x() + 1.0f) * 2.0f / realWinSize.width() - osdOffset.x();
+        const float top    = (bounds.top() + m_subsRect.y()) * 2.0f / realWinSize.height() - osdOffset.y();
+        const float bottom = (bounds.bottom() + m_subsRect.y() + 1.0f) * 2.0f / realWinSize.height() - osdOffset.y();
         const float verticesOSD[8] = {
             left  - 1.0f, -bottom + 1.0f,
             right - 1.0f, -bottom + 1.0f,
@@ -718,12 +721,8 @@ QByteArray OpenGLCommon::readShader(const QString &fileName, bool pure)
             shader = "precision highp float;\n";
         shader.append("#line 1\n");
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     const auto data = res.uncompressedData();
     shader.append(data.constData(), data.size());
-#else
-    shader.append((const char *)res.data(), res.size());
-#endif
     return shader;
 }
 
