@@ -141,15 +141,21 @@ Window::Window(const shared_ptr<HWInterop> &hwInterop)
     , m_instance(static_pointer_cast<Instance>(QMPlay2Core.gpuInstance()))
     , m_physicalDevice(m_instance->physicalDevice())
     , m_platformName(QGuiApplication::platformName())
-    , m_isWayland(m_platformName.contains("wayland"))
-    , m_passEventsToParent(m_platformName != "xcb" && m_platformName != "android")
+    , m_isWayland(m_platformName.contains(QStringLiteral("wayland")))
+    , m_isXcb(m_platformName == QStringLiteral("xcb"))
+    , m_passEventsToParent(
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+          !m_isWayland &&
+          m_platformName != QStringLiteral("windows") &&
+#endif
+          !m_isXcb && m_platformName != QStringLiteral("android"))
     , m_videoPipelineSpecializationData(sizeof(VideoPipelineSpecializationData) / sizeof(int))
     , m_frameProps(make_unique<FrameProps>())
 {
     setSurfaceType(VulkanSurface);
     setVulkanInstance(m_instance->qVulkanInstance());
 
-    if (m_platformName == "xcb" && !qgetenv("WAYLAND_DISPLAY").isEmpty())
+    if (m_isXcb && !qgetenv("WAYLAND_DISPLAY").isEmpty())
     {
         m_useRenderPassClear = true;
     }
@@ -178,7 +184,7 @@ Window::Window(const shared_ptr<HWInterop> &hwInterop)
     });
 
     m_widget = QWidget::createWindowContainer(this);
-    if (!m_isWayland && !m_platformName.contains("android"))
+    if (!m_isWayland && m_platformName != QStringLiteral("android"))
         m_widget->setAttribute(Qt::WA_NativeWindow);
     m_widget->grabGesture(Qt::PinchGesture);
     m_widget->installEventFilter(this);
@@ -200,7 +206,7 @@ Window::~Window()
 
 void Window::deleteWidget()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0) && QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     if (m_isWayland)
     {
         // "SurfaceAboutToBeDestroyed" is delivered too late when deleting a widget container (Qt bug, tested on 6.5.1)
@@ -245,7 +251,7 @@ void Window::setConfig(
         m_hqScaleUp = hqScaleUp;
         maybeRequestUpdate();
     }
-    if (QGuiApplication::platformName() == "xcb")
+    if (m_isXcb)
     {
        setX11BypassCompositor(bypassCompositor);
     }
@@ -261,7 +267,8 @@ void Window::setConfig(
             maybeRequestUpdate();
         }
     }
-    if (m_hdr != hdr)
+#endif
+    if ((m_isWayland || m_platformName == QStringLiteral("windows")) && m_hdr != hdr)
     {
         m_hdr = hdr;
         m.checkSurfaceColorSpace = true;
@@ -269,7 +276,6 @@ void Window::setConfig(
         m.mustUpdateVideoPipelineSpecialization = true;
         maybeRequestUpdate();
     }
-#endif
 }
 void Window::setParams(
     const QSize &imgSize,
@@ -574,7 +580,7 @@ void Window::render()
         const uint32_t imageIdx = m.swapChain->acquireNextImage(&suboptimal);
         if (!suboptimal || m.swapChain->maybeSuboptimal())
         {
-            auto submitInfo = m.swapChain->getSubmitInfo();
+            auto submitInfo = m.swapChain->getSubmitInfo(imageIdx);
             HWInterop::SyncDataPtr syncData;
             if (m_vkHwInterop)
                 syncData = m_vkHwInterop->sync({m_frame}, &submitInfo);
@@ -699,6 +705,7 @@ void Window::renderVideo()
 void Window::renderOSD()
 {
     const auto winSize = getRealWidgetSize();
+    const auto osdOffset = getOsdOffset();
 
     vector<MemoryObjectDescrs> osdAvMemoryObjects;
     vector<MemoryObjectDescrs> osdAssMemoryObjects;
@@ -794,8 +801,8 @@ void Window::renderOSD()
 
         QMatrix4x4 mat;
         mat.translate(
-            (-1.0 - m_osdOffset.x()) + (m_subsRect.x() + imgRect.x() * multiplier.x()) * 2.0 / winSize.width(),
-            (-1.0 - m_osdOffset.y()) + (m_subsRect.y() + imgRect.y() * multiplier.y()) * 2.0 / winSize.height()
+            (-1.0 - osdOffset.x()) + (m_subsRect.x() + imgRect.x() * multiplier.x()) * 2.0 / winSize.width(),
+            (-1.0 - osdOffset.y()) + (m_subsRect.y() + imgRect.y() * multiplier.y()) * 2.0 / winSize.height()
         );
         mat.scale(
             imgRect.width()  * 2.0 * multiplier.x() / winSize.width(),
@@ -1526,13 +1533,13 @@ bool Window::eventFilter(QObject *o, QEvent *e)
         case QEvent::Hide:
             if (m_isWayland)
             {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+# if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
                 // QWindow is reset when hiding a widget container without "SurfaceAboutToBeDestroyed" notification (Qt bug, tested on 6.5.1)
                 resetSurface();
-#else
+# else
                 // Destroy the surface to prevent "The Wayland connection experienced a fatal error: Invalid argument" (Qt bug, tested on 5.15.9+kde+r155)
                 destroy();
-#endif
+# endif
             }
             break;
         default:
